@@ -18,7 +18,7 @@ module Mail
           if content_part.multipart?
             content_part.parts.each{|part| add_part part}
           else
-            body content_part.body.to_s
+            body content_part.body.raw_source
           end
         end
       end
@@ -26,5 +26,3 @@ module Mail
   end
 end
 
-
-
